@@ -48,8 +48,9 @@ Usage::
     list_targets_for_policy_paginator: ListTargetsForPolicyPaginator = client.get_paginator("list_targets_for_policy")
     ```
 """
-from typing import Iterator, List
+from typing import Generic, Iterator, Sequence, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import ChildTypeType, CreateAccountStateType, PolicyTypeType
@@ -94,54 +95,64 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListAWSServiceAccessForOrganizationPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListAWSServiceAccessForOrganization)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListAWSServiceAccessForOrganization)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listawsserviceaccessfororganizationpaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAWSServiceAccessForOrganizationResponseTypeDef]:
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListAWSServiceAccessForOrganizationResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListAWSServiceAccessForOrganization.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListAWSServiceAccessForOrganization.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listawsserviceaccessfororganizationpaginator)
         """
 
 
 class ListAccountsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListAccounts)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListAccounts)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listaccountspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAccountsResponseTypeDef]:
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListAccountsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListAccounts.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListAccounts.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listaccountspaginator)
         """
 
 
 class ListAccountsForParentPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListAccountsForParent)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListAccountsForParent)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listaccountsforparentpaginator)
     """
 
     def paginate(
-        self, *, ParentId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAccountsForParentResponseTypeDef]:
+        self, *, ParentId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListAccountsForParentResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListAccountsForParent.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListAccountsForParent.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listaccountsforparentpaginator)
         """
 
 
 class ListChildrenPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListChildren)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListChildren)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listchildrenpaginator)
     """
 
@@ -150,146 +161,146 @@ class ListChildrenPaginator(Boto3Paginator):
         *,
         ParentId: str,
         ChildType: ChildTypeType,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListChildrenResponseTypeDef]:
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListChildrenResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListChildren.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListChildren.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listchildrenpaginator)
         """
 
 
 class ListCreateAccountStatusPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListCreateAccountStatus)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListCreateAccountStatus)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listcreateaccountstatuspaginator)
     """
 
     def paginate(
         self,
         *,
-        States: List[CreateAccountStateType] = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListCreateAccountStatusResponseTypeDef]:
+        States: Sequence[CreateAccountStateType] = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListCreateAccountStatusResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListCreateAccountStatus.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListCreateAccountStatus.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listcreateaccountstatuspaginator)
         """
 
 
 class ListDelegatedAdministratorsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListDelegatedAdministrators)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListDelegatedAdministrators)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listdelegatedadministratorspaginator)
     """
 
     def paginate(
-        self, *, ServicePrincipal: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDelegatedAdministratorsResponseTypeDef]:
+        self, *, ServicePrincipal: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListDelegatedAdministratorsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListDelegatedAdministrators.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListDelegatedAdministrators.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listdelegatedadministratorspaginator)
         """
 
 
 class ListDelegatedServicesForAccountPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListDelegatedServicesForAccount)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListDelegatedServicesForAccount)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listdelegatedservicesforaccountpaginator)
     """
 
     def paginate(
-        self, *, AccountId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListDelegatedServicesForAccountResponseTypeDef]:
+        self, *, AccountId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListDelegatedServicesForAccountResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListDelegatedServicesForAccount.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListDelegatedServicesForAccount.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listdelegatedservicesforaccountpaginator)
         """
 
 
 class ListHandshakesForAccountPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListHandshakesForAccount)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListHandshakesForAccount)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listhandshakesforaccountpaginator)
     """
 
     def paginate(
         self,
         *,
-        Filter: "HandshakeFilterTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListHandshakesForAccountResponseTypeDef]:
+        Filter: "HandshakeFilterTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListHandshakesForAccountResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListHandshakesForAccount.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListHandshakesForAccount.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listhandshakesforaccountpaginator)
         """
 
 
 class ListHandshakesForOrganizationPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListHandshakesForOrganization)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListHandshakesForOrganization)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listhandshakesfororganizationpaginator)
     """
 
     def paginate(
         self,
         *,
-        Filter: "HandshakeFilterTypeDef" = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListHandshakesForOrganizationResponseTypeDef]:
+        Filter: "HandshakeFilterTypeDef" = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListHandshakesForOrganizationResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListHandshakesForOrganization.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListHandshakesForOrganization.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listhandshakesfororganizationpaginator)
         """
 
 
 class ListOrganizationalUnitsForParentPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListOrganizationalUnitsForParent)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListOrganizationalUnitsForParent)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listorganizationalunitsforparentpaginator)
     """
 
     def paginate(
-        self, *, ParentId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListOrganizationalUnitsForParentResponseTypeDef]:
+        self, *, ParentId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListOrganizationalUnitsForParentResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListOrganizationalUnitsForParent.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListOrganizationalUnitsForParent.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listorganizationalunitsforparentpaginator)
         """
 
 
 class ListParentsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListParents)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListParents)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listparentspaginator)
     """
 
     def paginate(
-        self, *, ChildId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListParentsResponseTypeDef]:
+        self, *, ChildId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListParentsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListParents.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListParents.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listparentspaginator)
         """
 
 
 class ListPoliciesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListPolicies)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListPolicies)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listpoliciespaginator)
     """
 
     def paginate(
-        self, *, Filter: PolicyTypeType, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPoliciesResponseTypeDef]:
+        self, *, Filter: PolicyTypeType, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListPoliciesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListPolicies.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListPolicies.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listpoliciespaginator)
         """
 
 
 class ListPoliciesForTargetPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListPoliciesForTarget)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListPoliciesForTarget)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listpoliciesfortargetpaginator)
     """
 
@@ -298,54 +309,54 @@ class ListPoliciesForTargetPaginator(Boto3Paginator):
         *,
         TargetId: str,
         Filter: PolicyTypeType,
-        PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPoliciesForTargetResponseTypeDef]:
+        PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListPoliciesForTargetResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListPoliciesForTarget.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListPoliciesForTarget.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listpoliciesfortargetpaginator)
         """
 
 
 class ListRootsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListRoots)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListRoots)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listrootspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListRootsResponseTypeDef]:
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListRootsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListRoots.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListRoots.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listrootspaginator)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListTagsForResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListTagsForResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listtagsforresourcepaginator)
     """
 
     def paginate(
-        self, *, ResourceId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTagsForResourceResponseTypeDef]:
+        self, *, ResourceId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListTagsForResourceResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListTagsForResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListTagsForResource.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listtagsforresourcepaginator)
         """
 
 
 class ListTargetsForPolicyPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListTargetsForPolicy)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListTargetsForPolicy)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listtargetsforpolicypaginator)
     """
 
     def paginate(
-        self, *, PolicyId: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTargetsForPolicyResponseTypeDef]:
+        self, *, PolicyId: str, PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListTargetsForPolicyResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.8/reference/services/organizations.html#Organizations.Paginator.ListTargetsForPolicy.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.1/reference/services/organizations.html#Organizations.Paginator.ListTargetsForPolicy.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_organizations/paginators.html#listtargetsforpolicypaginator)
         """
